@@ -16,26 +16,22 @@ from pkg_resources import resource_filename
 from pickle import load as load_pickle
 import urllib
 
-urlbase = 'https://hastie.su.domains/ISLP/Data/IMDB/'
-
-md5sums = {'IMDB_X_train_size.tensor': '859a90e4c8617925fdf58d67c15d063b',
-           'IMDB_X_test_idx.tensor': '196829061c910afab8979822f2bdad5e',
-           'IMDB_Y_test.npy': 'bedbed694970384ebf48088dfee80d51',
+md5sums = {'IMDB_Y_test.npy': 'bedbed694970384ebf48088dfee80d51',
            'IMDB_Y_train.npy': '66bbcf3b4d43d2ddbafc03c2c5fbaab5',
-           'IMDB_X_train_values.tensor': '67da83ef8c8a53f7da2d28ef5b2ecc9f',
-           'IMDB_X_test_values.tensor': '4abfa952fe9466abaaf3ab7a8b140765',
            'IMDB_S_test.tensor': '02669d946d63aeede9b71abf3b8e811d',
-           'IMDB_X_test_size.tensor': '859a90e4c8617925fdf58d67c15d063b',
+           'IMDB_X_test.tensor': '75b9cc67bd7b34b1da664d1e4b2ea69d',
+           'IMDB_X_train.tensor': 'e34b5c4d2a4212f317408fe275785788',
            'IMDB_X_test.npz': 'd914c62cc0a3862067eea3cce955ea2b',
            'IMDB_S_train.tensor': '0c00ebbb1c050141bbfe90b19cf173dd',
            'IMDB_word_index.pkl': '5fa514f2ee6e3ea50a07e84711c42bbd',
            'IMDB_X_train.npz': '9d19e42410ca9264bd2c549122a842fa',
-           'IMDB_X_train_idx.tensor': '47368c12728797527d6a6e8217f3da64'}
+}
 
 
 def _get_imdb(imdb_file,
               outdir,
-              urlbase='https://hastie.su.domains/ISLP/Data/IMDB/'):
+              urlbase='https://hastie.su.domains/ISLP/Data/IMDB/',
+              ):
     if not os.path.exists(outdir):
         os.makedirs(outdir)
 
@@ -63,7 +59,8 @@ def _check_md5sum(imdb_file,
         # check md5 sum
         md5_hash = md5()
         md5_hash.update(raw_data)
-    return md5_hash.hexdigest() == md5sums[imdb_file]
+    _hash = md5_hash.hexdigest()
+    return _hash == md5sums[imdb_file]
 
 def load_lookup(root='.'):
     lookup_file = _get_imdb('IMDB_word_index.pkl',
@@ -86,10 +83,10 @@ def load_sparse(root='.',
                        for r in ['Y_test.npy',
                                  'Y_train.npy']]
     
-    np.random.seed(random_state)
+    rng = np.random.default_rng(random_state)
     mask = np.zeros(X_train.shape[0], bool)
     mask[:-int(validation)] = 1
-    np.random.shuffle(mask)
+    rng.shuffle(mask)
     
     X_train_tmp, Y_train_tmp = X_train, Y_train
     X_train, Y_train = X_train_tmp[mask], Y_train_tmp[mask]
@@ -102,24 +99,9 @@ def load_tensor(root='.'):
     Load IMDB features from ISLP package in `torch` sparse tensor format.
     """
 
-    (test_idx,
-     test_vals,
-     test_size) = [torch.load(_get_imdb(f'IMDB_{r}', root))
-                   for r in ['X_test_idx.tensor',
-                             'X_test_values.tensor',
-                             'X_test_size.tensor']]
-
-    X_test = torch.sparse_coo_tensor(test_idx, test_vals, test_size).coalesce()
+    X_test, X_train = [torch.load(_get_imdb(f'IMDB_{r}', root))
+                       for r in ['X_test.tensor', 'X_train.tensor']]
     
-    (train_idx,
-     train_vals,
-     train_size) = [torch.load(_get_imdb(f'IMDB_{r}', root))
-                   for r in ['X_train_idx.tensor',
-                             'X_train_values.tensor',
-                             'X_train_size.tensor']]
-
-    X_train = torch.sparse_coo_tensor(train_idx, train_vals, train_size).coalesce()
-
     Y_test, Y_train = [np.load(_get_imdb(f'IMDB_{r}', root))
                        for r in ['Y_test.npy',
                                  'Y_train.npy']]
